@@ -25,8 +25,8 @@
 #include <string.h>
 #include <time.h>
 
-#include <gphoto2-library.h>
-#include <gphoto2-port-log.h>
+#include <gphoto2/gphoto2-library.h>
+#include <gphoto2/gphoto2-port-log.h>
 
 #include "konica.h"
 
@@ -61,14 +61,14 @@ static struct {
         int vendor;
         int product;
 } konica_cameras[] = {
-        {"Konica:Q-EZ",        0, 0, 0},
-        {"Konica:Q-M100",      0, 0, 0},
-        {"Konica:Q-M100V",     0, 0, 0},
-        {"Konica:Q-M200",      1, 0, 0},
-        {"HP:PhotoSmart",      0, 0, 0},
-        {"HP:PhotoSmart C20",  0, 0, 0},
-        {"HP:PhotoSmart C30",  0, 0, 0},
-        {"HP:PhotoSmart C200", 0, 0, 0},
+        {"Konica Q-EZ",        0, 0, 0},
+        {"Konica Q-M100",      0, 0, 0},
+        {"Konica Q-M100V",     0, 0, 0},
+        {"Konica Q-M200",      1, 0, 0},
+        {"HP PhotoSmart",      0, 0, 0},
+        {"HP PhotoSmart C20",  0, 0, 0},
+        {"HP PhotoSmart C30",  0, 0, 0},
+        {"HP PhotoSmart C200", 0, 0, 0},
         {NULL,                 0, 0, 0}
 };
 
@@ -338,7 +338,7 @@ test_speed (Camera *camera, GPContext *context)
 	gp_context_progress_stop (context, id);
 	if (i == 10) {
 		gp_context_error (context, _("The camera could not be "
-			"contacted. Please make sure it is conntected to the "
+			"contacted. Please make sure it is connected to the "
 			"computer and turned on."));
 		return (GP_ERROR_IO);
 	}
@@ -642,8 +642,8 @@ camera_get_config (Camera* camera, CameraWidget** window, GPContext *context)
         time_t          t;
         float value_float;
         const char *name;
-        GP_SYSTEM_DIR d;
-        GP_SYSTEM_DIRENT de;
+        gp_system_dir d;
+        gp_system_dirent de;
 	unsigned int id;
 
         /* Get the current settings. */
@@ -669,7 +669,7 @@ camera_get_config (Camera* camera, CameraWidget** window, GPContext *context)
         if (status.date.year > 80) year_4_digits = status.date.year + 1900;
         else year_4_digits = status.date.year + 2000;
         tm_struct.tm_year = year_4_digits - 1900;
-        tm_struct.tm_mon = status.date.month;
+        tm_struct.tm_mon = status.date.month - 1;
         tm_struct.tm_mday = status.date.day;
         tm_struct.tm_hour = status.date.hour;
         tm_struct.tm_min = status.date.minute;
@@ -739,12 +739,12 @@ camera_get_config (Camera* camera, CameraWidget** window, GPContext *context)
         gp_widget_append (*window, section);
 
         /* Language */
-        d = GP_SYSTEM_OPENDIR (LOCALIZATION);
+        d = gp_system_opendir (LOCALIZATION);
         if (d) {
                 gp_widget_new (GP_WIDGET_MENU, _("Language"), &widget);
                 gp_widget_append (section, widget);
-                while ((de = GP_SYSTEM_READDIR (d))) {
-                        name = GP_SYSTEM_FILENAME (de);
+                while ((de = gp_system_readdir (d))) {
+                        name = gp_system_filename (de);
                         if (name && (*name != '.'))
                                 gp_widget_add_choice (widget, name);
                 }
@@ -883,7 +883,7 @@ camera_set_config (Camera *camera, CameraWidget *window, GPContext *context)
                 xtime = i;
                 tm_struct = localtime (&xtime);
                 date.year   = tm_struct->tm_year - 100;
-                date.month  = tm_struct->tm_mon;
+                date.month  = tm_struct->tm_mon + 1;
                 date.day    = tm_struct->tm_mday;
                 date.hour   = tm_struct->tm_hour;
                 date.minute = tm_struct->tm_min;
@@ -1099,8 +1099,10 @@ localization_file_read (Camera *camera, const char *file_name,
         /* Allocate the memory */
         *data_size = 0;
         *data = malloc (sizeof (char) * 65536);
-        if (!*data)
+        if (!*data) {
+		fclose (file);
                 return (GP_ERROR_NO_MEMORY);
+	}
 
         j = 0;
         line_number = 1;
@@ -1203,6 +1205,15 @@ camera_post_func (Camera *camera, GPContext *context)
 	return (GP_OK);
 }
 
+static CameraFilesystemFuncs fsfuncs = {
+	.get_info_func = get_info_func,
+	.set_info_func = set_info_func,
+	.file_list_func = file_list_func,
+	.get_file_func = get_file_func,
+	.del_file_func = delete_file_func,
+	.delete_all_func = delete_all_func,
+};
+
 int
 camera_init (Camera* camera, GPContext *context)
 {
@@ -1267,21 +1278,12 @@ camera_init (Camera* camera, GPContext *context)
         default:
                 return (GP_ERROR_UNKNOWN_PORT);
         }
-
         /* Set up the filesystem */
-	C(gp_filesystem_set_info_funcs (camera->fs, get_info_func,
-					set_info_func, camera));
-	C(gp_filesystem_set_list_funcs (camera->fs, file_list_func,
-					NULL, camera));
-	C(gp_filesystem_set_file_funcs (camera->fs, get_file_func,
-					delete_file_func, camera));
-	C(gp_filesystem_set_folder_funcs (camera->fs, NULL, delete_all_func,
-					NULL, NULL, camera));
+	C(gp_filesystem_set_funcs (camera->fs, &fsfuncs, camera));
 
 	/* Ping the camera every minute to prevent shut-down. */
 	camera->pl->timeout = gp_camera_start_timeout (camera, PING_TIMEOUT,
 						       timeout_func);
-
         return (GP_OK);
 }
 
